==> oryx-0.0.1.post4.tar.gz: oryx-0.0.1.post4/oryx/core/__init__.py <==
# Copyright 2020 The TensorFlow Probability Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================
"""Contains Oryx's core transformations and functionality."""
from oryx.core import interpreters
from oryx.core import ppl
from oryx.core import state
from oryx.core.interpreters.harvest import harvest
from oryx.core.interpreters.harvest import nest
from oryx.core.interpreters.harvest import plant
from oryx.core.interpreters.harvest import reap
from oryx.core.interpreters.harvest import sow
from oryx.core.interpreters.inverse import ildj
from oryx.core.interpreters.inverse import ildj_registry
from oryx.core.interpreters.inverse import inverse
from oryx.core.interpreters.inverse import inverse_and_ildj
from oryx.core.interpreters.log_prob import log_prob
from oryx.core.interpreters.log_prob import log_prob_registry
from oryx.core.interpreters.unzip import unzip
from oryx.core.interpreters.unzip import unzip_registry
from oryx.core.primitive import call_bind
from oryx.core.primitive import FlatPrimitive
from oryx.core.primitive import HigherOrderPrimitive
from oryx.core.primitive import tie_all
from oryx.core.primitive import tie_in
from oryx.core.pytree import Pytree
from oryx.core.serialize import deserialize
from oryx.core.serialize import serialize

==> oryx-0.2.2.tar.gz: oryx-0.2.2/oryx/core/__init__.py <==
# Copyright 2020 The TensorFlow Probability Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================
"""Contains Oryx's core transformations and functionality."""
from oryx.core import interpreters
from oryx.core import ppl
from oryx.core import primitive
from oryx.core import pytree
from oryx.core import serialize
from oryx.core import state
from oryx.core import trace_util
from oryx.core.interpreters.harvest import harvest
from oryx.core.interpreters.harvest import nest
from oryx.core.interpreters.harvest import plant
from oryx.core.interpreters.harvest import reap
from oryx.core.interpreters.harvest import sow
from oryx.core.interpreters.inverse.core import ildj
from oryx.core.interpreters.inverse.core import ildj_registry
from oryx.core.interpreters.inverse.core import inverse
from oryx.core.interpreters.inverse.core import inverse_and_ildj
from oryx.core.interpreters.inverse.custom_inverse import custom_inverse
from oryx.core.interpreters.inverse.custom_inverse import NonInvertibleError
from oryx.core.interpreters.log_prob import log_prob
from oryx.core.interpreters.log_prob import log_prob_registry
from oryx.core.interpreters.unzip import unzip
from oryx.core.interpreters.unzip import unzip_registry
from oryx.core.primitive import call_bind
from oryx.core.primitive import FlatPrimitive
from oryx.core.primitive import HigherOrderPrimitive
from oryx.core.primitive import tie_all
from oryx.core.primitive import tie_in
from oryx.core.pytree import Pytree
